<?php

/**
 * WAAVE Compliance
 *
 * @class       WC_WAAVE_Age_Gate
 * @version     1.0.1
 */
class WAAVE_Compiance_Age_Gate  {
	const API_PROD_URL = 'https://getwaave.co';
	const API_SANDBOX_URL = 'https://staging.getwaave.co';
	public static $instance;
	public static function init() {
		if (!self::$instance) {
		self::$instance = new WAAVE_Compiance_Age_Gate();
		}
		return self::$instance;
	}

	public function __construct() {
		// Configuration fields
		$this->venue_id = get_option( 'waave_compliance_venue_id' );
		$this->age_gate_mode = get_option('waave_compliance_age_gate_mode');
		$this->disclaimers_mode = get_option('waave_compliance_disclaimers_mode');
		$this->disclaimers_product = get_option('waave_compliance_disclaimers_product');
		$this->disclaimers_cart = get_option('waave_compliance_disclaimers_cart');
		$this->disclaimers_checkout = get_option('waave_compliance_disclaimers_checkout');
		$this->test_mode = get_option('waave_compliance_testmode');
		$this->waaveBackgroundColor = get_option('waave_compliance_disclaimers_background_color');
		$this->waaveColor = get_option('waave_compliance_disclaimers_color');
		
		//Api 
		$this->api_url = self::API_PROD_URL;
		if ('yes' == $this->test_mode) {
			$this->api_url = self::API_SANDBOX_URL;
		}

		add_action('wp_footer', array($this, 'age_verification_popup'));
		add_action('wp_footer', array($this, 'show_disclaimers_footer'));
		add_action('wp_footer', array($this, 'waave_compliance_add_footer'));
		add_action('wp_ajax_set_age_verification_cookie',array($this, 'set_age_verification_cookie'));
		add_action('wp_ajax_nopriv_set_age_verification_cookie',array($this, 'set_age_verification_cookie'));
		add_action('wp_enqueue_scripts', array($this, 'age_verification_assets') );
	}
	
	public function waave_compliance_add_footer() {
		echo '<div style="text-align: center; padding-top: 10px; background-color: '.$this->waaveBackgroundColor.'; color: '.$this->waaveColor.';">
			<img style="margin: 0 auto" src="' . esc_url( WAAVE_COMPLIANCE_PLUGIN_URL . '/assets/images/stamp.png' ) . '" alt="WAAVE Compliance" />
		</div>';
	}

	public function age_verification_assets() {
		wp_enqueue_script( 'age-verification', plugins_url( '../assets/js/age-verification-1.0.1.js', __FILE__ ), array('jquery'));
		wp_enqueue_style( 'age-verification', plugins_url( '../assets/css/age-verification-1.0.1.css', __FILE__) );

		wp_localize_script( 
			'age-verification', 
			'my_ajax_obj', 
			array(
				'ajax_url' => admin_url( 'admin-ajax.php' ),
				'nonce'    => wp_create_nonce( 'age-verification' )
			) 
		);
	}

	public function set_age_verification_cookie() {
		check_ajax_referer( 'age-verification' );
		
		if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
			if (isset($_COOKIE['remember_me'])) {
				$timeRemerberMe = 10 * 365 * 24 * 60 * 60; //10 years
				setcookie('age_verification', 1, time()+$timeRemerberMe, COOKIEPATH, COOKIE_DOMAIN );
			} else {
				setcookie('age_verification', 1, time()+(360), COOKIEPATH, COOKIE_DOMAIN );
			}
		}
		die();
	}

	public function age_verification_popup() {
		if ( ('yes' === $this->age_gate_mode) ) {
			if (!isset($_COOKIE['age_verification_mode'])) {
				$timeRemerberMe = 10 * 365 * 24 * 60 * 60; //10 years
				setcookie('age_verification_mode', get_option('waave_compliance_age_gate_mode') == 'yes' ? 1 : 0, time()+$timeRemerberMe, COOKIEPATH, COOKIE_DOMAIN );
			}
			if(!isset($_COOKIE['age_verification'])) { 
				$clientAva = "";
				$ageGateInfo = $this->get_age_gate_info_categories();
				if ($ageGateInfo) {
					$clientAva = $ageGateInfo['client_logo']['original'];
					if (isset($ageGateInfo['data'])) {
						$text_Popup ='';
						foreach ($ageGateInfo['data'] as $vertical) {
							$textTennesse = $vertical['tennessee_age'] ? ' or '.$vertical['tennessee_age'].'+ if in Tennesse' : '';
							$isIdRequired = $vertical['is_id_required'] ? "ID Required" : '';
							$text_Popup = $text_Popup .'You must be '.$vertical['age'].'+ '.$isIdRequired.$textTennesse.' to purchase '.$vertical['name'].' products </br>';
						}
						if ($clientAva == "") {
							$clientAva = $this->api_url.'/images/no-image.png';
						}
						echo "
						<div class='age-verification-overlay'>
							<div class='age-verification-popup'>
								<img class='age-verification-client-img' src='$clientAva' alt=''>
								<h3 class='age-verification-title'>Welcome!</h3>
								<p class='age-verification-q'>
								$text_Popup
								</p>
								<p>
									<a class='age-verification-btn age-verification-btn-yes' href='#'>I am</a>
									<a class='age-verification-btn age-verification-btn-no' href='https://google.com'>I am not</a>
								</p>
								<div class='age-gate-remember-me'>
									<input type='checkbox' class='age-gate-remember-me-checkbox'>
									<span>Remember Me</span>
								</div>
							</div>
						</div>";
					}
				}
			}
		}
	}
	
	public function show_disclaimers_footer() {
		if ( 'yes' === $this->disclaimers_mode ) {
			$mssDisclaimers ='';
			$hcron = 7; // 07:00 AM
			date_default_timezone_set('America/Los_Angeles');
			$now = new DateTime('now', new DateTimeZone('America/Los_Angeles'));
			$timeNow = $now->format('Y-m-d H:i:s');
			$now = new DateTime('now', new DateTimeZone('America/Los_Angeles'));
			$on7Hour = $now->setTime($hcron, 00)->format('Y-m-d H:i:s');
			$afterDay = new DateTime('now +1 day', new DateTimeZone('America/Los_Angeles'));
			$on7HourAfterDay = $afterDay->setTime($hcron, 00)->format('Y-m-d H:i:s');


			$waaveDisclaimerCache = get_transient( 'waave_disclaimer' );
			if ($waaveDisclaimerCache) {
				if (($waaveDisclaimerCache['time_updated']<$on7Hour) || (($waaveDisclaimerCache['time_updated'] == $on7Hour) && ($timeNow >= $on7Hour))) {
					$verticalsCache = $this->get_age_gate_info_categories();
					$verticalsCache['time_updated'] = $on7HourAfterDay;
					set_transient( 'waave_disclaimer', $verticalsCache );
				} 
			} else {
				$verticalsCache = $this->get_age_gate_info_categories();
				$verticalsCache['time_updated'] = $on7HourAfterDay;
				set_transient( 'waave_disclaimer', $verticalsCache );
			}
			$verticals = get_transient( 'waave_disclaimer' );
			if (isset($verticals['data'])) {
				$mssDisclaimers = 'Disclaimer: ';
				foreach ($verticals['data'] as $vertical) {
				if ($vertical['disclaimer']) {
						$mssDisclaimers = $mssDisclaimers.$vertical['disclaimer'].'&nbsp';
					}
				}
			}
			if ($mssDisclaimers != '') {
				echo "<div class='waave-compliance-mode' style='margin: unset; background-color: $this->waaveBackgroundColor; color: $this->waaveColor;'>
					<div class='waave-compliance-disclaimer-content'>
						$mssDisclaimers
					</div>
					<hr class='waave-compliance-disclaimer-hr'>
				</div>";
			}
		}
	}

	private function get_age_gate_info_categories() {
		$venue_id = get_option('waave_compliance_venue_id');
		if (is_plugin_inactive('waave-compliance/waave-compliance.php')) {
			$venue_id = $this->venue_id;
		}
		$url = $this->api_url . '/compliance/categories/age-gate/'.$venue_id;
		$request  = wp_remote_get( $url);
		$response = json_decode( wp_remote_retrieve_body( $request ), true );
		return $response;
	}
}
?>