<?php


use Automattic\WooCommerce\Client;

class WAAVE_Compiance_REST_API {

  const MAX_PER_PAGE = 100;

  static $woocommerce;

  public static function init() {
    if ( ! function_exists( 'register_rest_route' ) ) {
      return false;
    }

    register_rest_route( 'waave-compliance/v1', '/products', array(
      array(
        'methods' => WP_REST_Server::READABLE,
        'callback' => array( 'WAAVE_Compiance_REST_API', 'get_products' ),
        'permission_callback' => array('WAAVE_Compiance_REST_API', 'permissions_check')
      )
    ));

    register_rest_route( 'waave-compliance/v1', '/products/categories', array(
      array(
        'methods' => WP_REST_Server::READABLE,
        'callback' => array( 'WAAVE_Compiance_REST_API', 'get_products_categories' ),
        'permission_callback' => array('WAAVE_Compiance_REST_API', 'permissions_check')
      )
    ));

    register_rest_route( 'waave-compliance/v1', '/version', array(
      array(
        'methods' => WP_REST_Server::READABLE,
        'callback' => array( 'WAAVE_Compiance_REST_API', 'get_plugin_version' ),
        'permission_callback' => array('WAAVE_Compiance_REST_API', 'permissions_check')
      )
    ));

    register_rest_route( 'waave-compliance/v1', '/disclaimer/sync', array(
      array(
        'methods' => WP_REST_Server::READABLE,
        'callback' => array( 'WAAVE_Compiance_REST_API', 'sync_disclaimer' ),
        'permission_callback' => array('WAAVE_Compiance_REST_API', 'permissions_check')
      )
    ));

    add_filter( "woocommerce_rest_product_object_query", function( $args, $request ) {
      $after = $request->get_param('after');
      if ($after) {
        $args['date_query'][0]['column'] = 'post_modified';
      }
      return $args;
    }, 10, 2);
  }

  public static function get_plugin_version() {
    if( ! function_exists('get_plugin_data') ){
        require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
    }
    $data = get_plugin_data(WAAVE_COMPLIANCE_MAIN_FILE);
    if (is_plugin_active('waave-complete/woocommer-waave-complete.php')) {
      $complete = get_plugin_data(WC_WAAVE_MAIN_FILE);
    }
    if (is_plugin_active('waave-plugin/woocommer-gateway-waave.php')) {
      $checkout = get_plugin_data(WC_WAAVE_PLUGIN_PATH);
    }

    $versions = [
      'compliance' => $data['Version'],
    ];
    if (isset($complete)) {
      $versions['complete'] = $complete['Version'];
    }
    if (isset($checkout)) {
      $versions['checkout'] = $checkout['Version'];
    }

    return $versions;
  }

  public static function get_products( $request ) {
    $page = $request->get_param('page');
    $order = $request->get_param('order');
    $orderby = $request->get_param('orderby');
    $search = $request->get_param('search');
    $category = $request->get_param('category');
    $slug = $request->get_param('slug');
    $after = $request->get_param('after');

    if (empty($page)) {
      $page = 1;
    }

    $options = [
      'page' => $page,
      'per_page' => self::MAX_PER_PAGE,
      'status' => 'any'
    ];

    if ($order) {
      $options['order'] = $order;
    }

    if ($orderby) {
      $options['orderby'] = $orderby;
    }

    if ($search) {
      $options['search'] = $search;
    }

    if ($category) {
      $options['category'] = $category;
    }

    if ($slug) {
      $options['slug'] = $slug;
    }

    if ($after) {
      $options['after'] = $after;
    }

    $woocommerce = self::create_woocommerce_client();
    $products = $woocommerce->get('products', $options);

    if (count($products) < self::MAX_PER_PAGE) {
        return $products;
    }

    $request->set_param('page', ++$page);
    return array_merge($products, self::get_products($request));
  }

  public static function get_products_categories( $request ) {
    $page = $request->get_param('page');
    $order = $request->get_param('order');
    $orderby = $request->get_param('orderby');
    $search = $request->get_param('search');
    $slug = $request->get_param('slug');

    if (empty($page)) {
      $page = 1;
    }

    $options = [
      'page' => $page,
      'per_page' => self::MAX_PER_PAGE
    ];

    if ($order) {
      $options['order'] = $order;
    }

    if ($orderby) {
      $options['orderby'] = $orderby;
    }

    if ($search) {
      $options['search'] = $search;
    }

    if ($slug) {
      $options['slug'] = $slug;
    }

    $woocommerce = self::create_woocommerce_client();
    $categories = $woocommerce->get('products/categories', $options);

    if (count($categories) < self::MAX_PER_PAGE) {
      return $categories;
    }

    $request->set_param('page', ++$page);
    return array_merge($categories, self::get_products_categories($request));
  }

  public static function sync_disclaimer( $request ) {
    $hcron = 7; // 07:00 AM
    date_default_timezone_set('America/Los_Angeles');
    $now = new DateTime('now', new DateTimeZone('America/Los_Angeles'));
    $timeNow = $now->format('Y-m-d H:i:s');
    $now = new DateTime('now', new DateTimeZone('America/Los_Angeles'));
    $on7Hour = $now->setTime($hcron, 00)->format('Y-m-d H:i:s');
    $afterDay = new DateTime('now +1 day', new DateTimeZone('America/Los_Angeles'));
    $on7HourAfterDay = $afterDay->setTime($hcron, 00)->format('Y-m-d H:i:s');

    if ('yes' == get_option('waave_compliance_testmode')) {
      $waaveApiPRDUrl = 'https://staging.getwaave.co';
		} else {
      $waaveApiPRDUrl = 'https://getwaave.co';
    }

    $venue_id = get_option('waave_compliance_venue_id');
		if (is_plugin_inactive('waave-compliance/waave-compliance.php')) {
			$venue_id = get_option( 'waave_compliance_venue_id' );
		}
		$url = $waaveApiPRDUrl . '/compliance/categories/age-gate/'.$venue_id;
		$request  = wp_remote_get( $url);
    $verticalsCache = json_decode( wp_remote_retrieve_body( $request ), true );
    $verticalsCache['time_updated'] = $on7HourAfterDay;
    set_transient( 'waave_disclaimer', $verticalsCache ); 
    return wp_send_json( $verticalsCache, 200 , 0 );
  }

  public static function permissions_check()
  {
    return true;
  }

  private static function create_woocommerce_client() {
    if (self::$woocommerce) {
      return self::$woocommerce;
    }

    $url = get_site_url();
    $consumer_key = get_option( 'waave_compliance_consumer_key' );
    $consumer_secret = get_option( 'waave_compliance_consumer_secret' );

    $options = [
      'query_string_auth' => true
    ];

    self::$woocommerce = new Client(
      $url,
      $consumer_key,
      $consumer_secret,
      $options
    );

    return self::$woocommerce;
  }
}
