<?php

class WAAVE_Compliance {
  const PROD_URL = 'https://getwaave.co/compliance/active';
  const SANDBOX_URL = 'https://staging.getwaave.co/compliance/active';

  public static $instance;

  public static function init() {
    if (!self::$instance) {
      self::$instance = new WAAVE_Compliance();
    }

    return self::$instance;
  }

  public function __construct() {
    add_filter( 'woocommerce_settings_tabs_array', array( $this, 'add_settings_tab' ), 99 );
    add_action( 'woocommerce_settings_waave', array( $this, 'settings_tab' ) );
    add_action( 'woocommerce_update_options_waave', array( $this, 'update_settings' ) );
  }

  public function add_settings_tab($settings_tabs) {
    $this->call_waave_active_api();
    $settings_tabs['waave'] = 'WAAVE';
    return $settings_tabs;
  }

  public function settings_tab() {
    woocommerce_admin_fields($this->get_settings());
  }

  public function update_settings() {
    woocommerce_update_options($this->get_settings());
    $this->call_waave_active_api();
    $timeRemerberMe = 10 * 365 * 24 * 60 * 60; //10 years
    setcookie('age_verification_mode', get_option('waave_compliance_age_gate_mode') == 'yes' ? 1 : 0, time()+$timeRemerberMe, COOKIEPATH, COOKIE_DOMAIN );
  }

  private function get_settings() {
    return array(
        'section_age_gate_title' => array(
          'name'     => __( 'Age Gate & Disclaimers', 'waave-compliance' ),
          'type'     => 'title',
          'desc'     => '',
          'id'       => 'waave_compliance_age_gate_title'
        ),
        'age_gate_mode' => array(
          'name'        => __( 'WAAVE Age Gate Mode', 'waave-compliance' ),
          'type'        => 'checkbox',
          'id'          => 'waave_compliance_age_gate_mode',
          'desc'          => 'Enable/Disable',
          'default'     => 'yes'
        ),
        'disclaimers_mode' => array(
          'name'        => __( 'WAAVE Disclaimers Mode', 'waave-compliance' ),
          'type'        => 'checkbox',
          'id'          => 'waave_compliance_disclaimers_mode',
          'desc'          => 'Enable/Disable',
          'default'     => 'yes'
        ),
        'disclaimers_background_color' => array(
          'name'        => __( '', 'waave-compliance' ),
          'type'        => 'color',
          'id'          => 'waave_compliance_disclaimers_background_color',
          'desc'     => 'Background Waave Footer Color',
          'default'     => '#fff'
        ),
        'disclaimers_color' => array(
          'name'        => __( '', 'waave-compliance' ),
          'type'        => 'color',
          'id'          => 'waave_compliance_disclaimers_color',
          'desc'     => 'Waave Footer Color',
          'default'     => '#111'
        ),
        'section_age_gate_end' => array(
          'type'      => 'sectionend',
          'id'      => 'waave_compliance_age_gate_section_end'
        ),
        'section_title' => array(
            'name'     => __( 'REST API', 'waave-compliance' ),
            'type'     => 'title',
            'desc'     => '',
            'id'       => 'waave_compliance_section_title'
        ),
        'consumer_key' => array(
            'name' => __( 'Consumer key', 'waave-compliance' ),
            'type' => 'text',
            'desc' => '',
            'id'   => 'waave_compliance_consumer_key'
        ),
        'consumer_secret' => array(
            'name' => __( 'Consumer secret', 'waave-compliance' ),
            'type' => 'password',
            'desc' => '',
            'id'   => 'waave_compliance_consumer_secret'
        ),
        'section_end' => array(
             'type' => 'sectionend',
             'id' => 'waave_compliance_section_end'
        ),
        'section_client_title' => array(
            'name'     => __( 'Client', 'waave-compliance' ),
            'type'     => 'title',
            'desc'     => '',
            'id'       => 'waave_compliance_section_client_title'
        ),
        'testmode' => array(
            'name'    => __( 'WAAVE Sandbox', 'waave-compliance' ),
            'type'    => 'checkbox',
            'id'      => 'waave_compliance_testmode',
            'default' => 'yes'
        ),
        'venue_id' => array(
            'name' => __( 'Venue ID', 'waave-compliance' ),
            'type' => 'text',
            'desc' => '',
            'id'   => 'waave_compliance_venue_id'
        ),
        'client_password' => array(
            'name' => __( 'Password', 'waave-compliance' ),
            'type' => 'password',
            'desc' => '',
            'id'   => 'waave_compliance_client_password'
        ),
        'section_client_end' => array(
             'type' => 'sectionend',
             'id' => 'waave_compliance_section_client_end'
        )
    );
  }

  private function call_waave_active_api() {
    $version = $this->get_plugin_version();
    $body = array(
      'version' => $version['version'],
      'ping_url' => get_rest_url(null, 'waave-compliance/v1/version'),
      'category_url' => get_rest_url(null, 'waave-compliance/v1/products/categories'),
      'menu_item_url' => get_rest_url(null, 'waave-compliance/v1/products'),
      'disclaimer_sync_url' => get_rest_url(null, 'waave-compliance/v1/disclaimer/sync'),
      'venue_id' => get_option('waave_compliance_venue_id'),
      'password' => get_option('waave_compliance_client_password')
    );

    $url = self::PROD_URL;
    if ('yes' == get_option('waave_compliance_testmode')) {
      $url = self::SANDBOX_URL;
    }

    $options = array(
      'body' => $body
    );

    $request  = wp_remote_post( $url, $options );
    $response = json_decode( wp_remote_retrieve_body( $request ), true );

    if (empty($response['success'])) {
      WC_Admin_Settings::add_error($response['message']);
    }
  }

  private function get_plugin_version() {
    if( ! function_exists('get_plugin_data') ){
        require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
    }
    $data = get_plugin_data(WAAVE_COMPLIANCE_MAIN_FILE);
    return array('version' => $data['Version']);
  }
}